==> google-cloud-datastream-1.0.1.tar.gz: google-cloud-datastream-1.0.1/google/cloud/datastream_v1alpha1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.datastream import DatastreamAsyncClient, DatastreamClient
from .types.datastream import (
    CreateConnectionProfileRequest,
    CreatePrivateConnectionRequest,
    CreateRouteRequest,
    CreateStreamRequest,
    DeleteConnectionProfileRequest,
    DeletePrivateConnectionRequest,
    DeleteRouteRequest,
    DeleteStreamRequest,
    DiscoverConnectionProfileRequest,
    DiscoverConnectionProfileResponse,
    FetchErrorsRequest,
    FetchErrorsResponse,
    FetchStaticIpsRequest,
    FetchStaticIpsResponse,
    GetConnectionProfileRequest,
    GetPrivateConnectionRequest,
    GetRouteRequest,
    GetStreamRequest,
    ListConnectionProfilesRequest,
    ListConnectionProfilesResponse,
    ListPrivateConnectionsRequest,
    ListPrivateConnectionsResponse,
    ListRoutesRequest,
    ListRoutesResponse,
    ListStreamsRequest,
    ListStreamsResponse,
    OperationMetadata,
    UpdateConnectionProfileRequest,
    UpdateStreamRequest,
)
from .types.datastream_resources import (
    AvroFileFormat,
    ConnectionProfile,
    DestinationConfig,
    Error,
    ForwardSshTunnelConnectivity,
    GcsDestinationConfig,
    GcsFileFormat,
    GcsProfile,
    JsonFileFormat,
    MysqlColumn,
    MysqlDatabase,
    MysqlProfile,
    MysqlRdbms,
    MysqlSourceConfig,
    MysqlSslConfig,
    MysqlTable,
    NoConnectivitySettings,
    OracleColumn,
    OracleProfile,
    OracleRdbms,
    OracleSchema,
    OracleSourceConfig,
    OracleTable,
    PrivateConnection,
    PrivateConnectivity,
    Route,
    SchemaFileFormat,
    SourceConfig,
    StaticServiceIpConnectivity,
    Stream,
    Validation,
    ValidationMessage,
    ValidationResult,
    VpcPeeringConfig,
)

__all__ = (
    "DatastreamAsyncClient",
    "AvroFileFormat",
    "ConnectionProfile",
    "CreateConnectionProfileRequest",
    "CreatePrivateConnectionRequest",
    "CreateRouteRequest",
    "CreateStreamRequest",
    "DatastreamClient",
    "DeleteConnectionProfileRequest",
    "DeletePrivateConnectionRequest",
    "DeleteRouteRequest",
    "DeleteStreamRequest",
    "DestinationConfig",
    "DiscoverConnectionProfileRequest",
    "DiscoverConnectionProfileResponse",
    "Error",
    "FetchErrorsRequest",
    "FetchErrorsResponse",
    "FetchStaticIpsRequest",
    "FetchStaticIpsResponse",
    "ForwardSshTunnelConnectivity",
    "GcsDestinationConfig",
    "GcsFileFormat",
    "GcsProfile",
    "GetConnectionProfileRequest",
    "GetPrivateConnectionRequest",
    "GetRouteRequest",
    "GetStreamRequest",
    "JsonFileFormat",
    "ListConnectionProfilesRequest",
    "ListConnectionProfilesResponse",
    "ListPrivateConnectionsRequest",
    "ListPrivateConnectionsResponse",
    "ListRoutesRequest",
    "ListRoutesResponse",
    "ListStreamsRequest",
    "ListStreamsResponse",
    "MysqlColumn",
    "MysqlDatabase",
    "MysqlProfile",
    "MysqlRdbms",
    "MysqlSourceConfig",
    "MysqlSslConfig",
    "MysqlTable",
    "NoConnectivitySettings",
    "OperationMetadata",
    "OracleColumn",
    "OracleProfile",
    "OracleRdbms",
    "OracleSchema",
    "OracleSourceConfig",
    "OracleTable",
    "PrivateConnection",
    "PrivateConnectivity",
    "Route",
    "SchemaFileFormat",
    "SourceConfig",
    "StaticServiceIpConnectivity",
    "Stream",
    "UpdateConnectionProfileRequest",
    "UpdateStreamRequest",
    "Validation",
    "ValidationMessage",
    "ValidationResult",
    "VpcPeeringConfig",
)

==> google-cloud-datastream-1.3.0.tar.gz: google-cloud-datastream-1.3.0/google/cloud/datastream_v1alpha1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.datastream import gapic_version as package_version

__version__ = package_version.__version__


from .services.datastream import DatastreamAsyncClient, DatastreamClient
from .types.datastream import (
    CreateConnectionProfileRequest,
    CreatePrivateConnectionRequest,
    CreateRouteRequest,
    CreateStreamRequest,
    DeleteConnectionProfileRequest,
    DeletePrivateConnectionRequest,
    DeleteRouteRequest,
    DeleteStreamRequest,
    DiscoverConnectionProfileRequest,
    DiscoverConnectionProfileResponse,
    FetchErrorsRequest,
    FetchErrorsResponse,
    FetchStaticIpsRequest,
    FetchStaticIpsResponse,
    GetConnectionProfileRequest,
    GetPrivateConnectionRequest,
    GetRouteRequest,
    GetStreamRequest,
    ListConnectionProfilesRequest,
    ListConnectionProfilesResponse,
    ListPrivateConnectionsRequest,
    ListPrivateConnectionsResponse,
    ListRoutesRequest,
    ListRoutesResponse,
    ListStreamsRequest,
    ListStreamsResponse,
    OperationMetadata,
    UpdateConnectionProfileRequest,
    UpdateStreamRequest,
)
from .types.datastream_resources import (
    AvroFileFormat,
    ConnectionProfile,
    DestinationConfig,
    Error,
    ForwardSshTunnelConnectivity,
    GcsDestinationConfig,
    GcsFileFormat,
    GcsProfile,
    JsonFileFormat,
    MysqlColumn,
    MysqlDatabase,
    MysqlProfile,
    MysqlRdbms,
    MysqlSourceConfig,
    MysqlSslConfig,
    MysqlTable,
    NoConnectivitySettings,
    OracleColumn,
    OracleProfile,
    OracleRdbms,
    OracleSchema,
    OracleSourceConfig,
    OracleTable,
    PrivateConnection,
    PrivateConnectivity,
    Route,
    SchemaFileFormat,
    SourceConfig,
    StaticServiceIpConnectivity,
    Stream,
    Validation,
    ValidationMessage,
    ValidationResult,
    VpcPeeringConfig,
)

__all__ = (
    "DatastreamAsyncClient",
    "AvroFileFormat",
    "ConnectionProfile",
    "CreateConnectionProfileRequest",
    "CreatePrivateConnectionRequest",
    "CreateRouteRequest",
    "CreateStreamRequest",
    "DatastreamClient",
    "DeleteConnectionProfileRequest",
    "DeletePrivateConnectionRequest",
    "DeleteRouteRequest",
    "DeleteStreamRequest",
    "DestinationConfig",
    "DiscoverConnectionProfileRequest",
    "DiscoverConnectionProfileResponse",
    "Error",
    "FetchErrorsRequest",
    "FetchErrorsResponse",
    "FetchStaticIpsRequest",
    "FetchStaticIpsResponse",
    "ForwardSshTunnelConnectivity",
    "GcsDestinationConfig",
    "GcsFileFormat",
    "GcsProfile",
    "GetConnectionProfileRequest",
    "GetPrivateConnectionRequest",
    "GetRouteRequest",
    "GetStreamRequest",
    "JsonFileFormat",
    "ListConnectionProfilesRequest",
    "ListConnectionProfilesResponse",
    "ListPrivateConnectionsRequest",
    "ListPrivateConnectionsResponse",
    "ListRoutesRequest",
    "ListRoutesResponse",
    "ListStreamsRequest",
    "ListStreamsResponse",
    "MysqlColumn",
    "MysqlDatabase",
    "MysqlProfile",
    "MysqlRdbms",
    "MysqlSourceConfig",
    "MysqlSslConfig",
    "MysqlTable",
    "NoConnectivitySettings",
    "OperationMetadata",
    "OracleColumn",
    "OracleProfile",
    "OracleRdbms",
    "OracleSchema",
    "OracleSourceConfig",
    "OracleTable",
    "PrivateConnection",
    "PrivateConnectivity",
    "Route",
    "SchemaFileFormat",
    "SourceConfig",
    "StaticServiceIpConnectivity",
    "Stream",
    "UpdateConnectionProfileRequest",
    "UpdateStreamRequest",
    "Validation",
    "ValidationMessage",
    "ValidationResult",
    "VpcPeeringConfig",
)
